<?php
/**
 * Single question Template for YITH WooCommerce Questions and Answers
 *
 * @author        Yithemes
 * @package YITH_WooCommerce_Questions_and_Answers_Premium
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! function_exists( 'answer_now_link' ) ) {

	/**
	 * Answer_now_link
	 *
	 * @param  mixed $question .
	 * @param  mixed $label html label.
	 * @param  mixed $class css class.
	 * @return string
	 */
	function answer_now_link( $question, $label, $class = '' ) {

		$classes = 'goto-question';
		if ( ! empty( $class ) ) {
			$classes .= ' ' . $class;
		}
		$link = '<a rel="nofollow" class="' . $classes . '" data-discussion-id="' . $question->ID . '" href="' . add_query_arg(
			array(
				'reply-to-question' => $question->ID,
				'qa'                => 1,
			),
			remove_query_arg( 'show-all-questions', get_permalink( $question->product_id ) )
		) . '">' .
		ywqa_strip_trim_text(
			$label,
			/**
			 * APPLY_FILTERS: ywqa_single_question_excerpt
			 *
			 * Filter for the $chars parameter of the ywqa_strip_trim_text method that specifies the number of characters to display before the ellipses. Default 100.
			 *
			 * @param int the default message.
			 *
			 * @return int
			 */
			apply_filters( 'ywqa_single_question_excerpt', 100 )
		) . '</a>';

		return $link;
	}
}

$all_answers         = $question->get_answers();
$all_answers_ordered = array_reverse( $all_answers );

$count            = $question->get_answers_count();
$answers_to_show  = intval( get_option( 'ywqa_answers_to_show', '0' ) );
$question_content = answer_now_link( $question, $question->content );

if ( ! current_user_can( 'administrator' ) && get_option( 'ywqa_only_admin_answers', 'no' ) === 'yes' ) {
	$only_admin_can_reply = false;
} else {
	$only_admin_can_reply = true;
}

?>

<?php if ( ( YITH_YWQA()->answer_excerpt_length > 0 ) && ( strlen( $question->content ) > YITH_YWQA()->answer_excerpt_length ) ) : ?>
	<span class="answer"><?php echo substr( $question->content, 0, YITH_YWQA()->answer_excerpt_length ) . '...'; // phpcs:ignore ?></span>
	<a href="#" rel="nofollow" data-discussion-id="<?php echo esc_attr( $question->ID ); ?>" class="read-more">
		<?php esc_html_e( 'Read more', 'yith-woocommerce-questions-and-answers' ); ?>
	</a>
<?php else : ?>
	<span class="answer"><?php echo $question->content; // phpcs:ignore ?></span>
<?php endif; ?>

<li id="li-question-<?php echo esc_attr( $question->ID ); ?>" class="question-container <?php echo esc_attr( $classes ); ?>">
	<?php
	/**
	 * DO_ACTION: yith_questions_answers_before_content
	 *
	 * Triggered questions answers before content.
	 *
	 * @param YITH_YCQA_Question $question the question object
	 */
	do_action( 'yith_questions_answers_before_content', $question );
	?>

	<div class="question-text <?php echo esc_attr( $classes ); ?>">
		<div class="question-content">
			<span class="question-symbol"><?php esc_html_e( 'Q', 'yith-woocommerce-questions-and-answers' ); ?></span>


			<?php if ( strlen( $question->content ) > apply_filters( 'ywqa_single_question_excerpt', 100 ) ) : ?>
				<span class="question"><?php echo ywqa_strip_trim_text( $question->content, apply_filters( 'ywqa_single_question_excerpt', 100 ) ) . '...'; // phpcs:ignore ?> </span>
				<input type="hidden" class="full-question-content" value="<?php echo esc_attr( $question->content ); ?>">
				<a href="#" rel="nofollow" class="question-read-more">
					<?php esc_html_e( 'Read more', 'yith-woocommerce-questions-and-answers' ); ?>
				</a>
			<?php else : ?>
				<span class="question"><?php echo ywqa_strip_trim_text( $question_content, apply_filters( 'ywqa_single_question_excerpt', 100 ) ); // phpcs:ignore ?></span>
			<?php endif; ?>





				<?php
				if ( $only_admin_can_reply && $all_answers_ordered && ( apply_filters( 'yith_wcqa_allow_user_to_reply', true ) ) ) :
					echo answer_now_link( $question, esc_html__( 'answer now', 'yith-woocommerce-questions-and-answers' ), 'answer-now' ); // phpcs:ignore
				endif;
				?>
			</span>
			<span class="question-owner-co">
				<?php if ( YITH_YWQA()->anonymise_user && ! YITH_YWQA()->anonymise_date ) : ?>
					<div class="question-owner">
					<?php
					echo sprintf(
						// translators: %s is the date when the question was asked.
						esc_html__( 'Asked on %s', 'yith-woocommerce-questions-and-answers' ),
						'<span class="question-date">' . date_i18n( get_option( 'date_format' ) . ' ' . get_option( 'time_format' ), strtotime( $question->date ) ) . '</span>' // phpcs:ignore
					);
					?>
				</div>
				<?php elseif ( YITH_YWQA()->anonymise_date && ! YITH_YWQA()->anonymise_user ) : ?>
					<div class="question-owner">
					<?php
					echo sprintf(
						// translators: %s is the name of the use who asked the question.
						esc_html__( 'Asked by %s', 'yith-woocommerce-questions-and-answers' ),
						'<span class="question-author-name">' . $question->get_author_name() . '</span>' // phpcs:ignore
					);
					?>
				</div>
				<?php elseif ( ! YITH_YWQA()->anonymise_date && ! YITH_YWQA()->anonymise_user ) : ?>
					<div class="question-owner">
					<?php
					echo sprintf(
						// translators: %1$s is the date when the question was asked. %2$s is the name of the use who asked the question.
						esc_html__( 'Asked by %1$s on %2$s', 'yith-woocommerce-questions-and-answers' ),
						'<span class="question-author-name">' . $question->get_author_name() . '</span>', // phpcs:ignore
						'<span class="question-date">' . date_i18n( get_option( 'date_format' ) . ' ' . get_option( 'time_format' ), strtotime( $question->date ) ) . '</span>' // phpcs:ignore
					);
					?>
				</div>
				<?php endif; ?>
			</span>
		</div>

		<div class="answer-content">

			<?php
			if ( $all_answers_ordered ) :


				$cnt = 0;

				foreach ( $all_answers_ordered as $answer ) {

					if ( $cnt >= $answers_to_show && 0 !== $answers_to_show ) {
						break;
					}
					$user_can         = user_can( $answer->discussion_author_id, 'manage_options' );
					/**
					 * APPLY_FILTERS: yith_ywqa_show_as_admin_capabilities
					 *
					 * Filter for the variable that determines if the answer  was made by an administrator.
					 *
					 * @param bool $user_can if the user that answered is an administrator.
					 * @param mixed $answer the answer
					 *
					 * @return bool
					 */
					$replied_by_admin = apply_filters( 'yith_ywqa_show_as_admin_capabilities', $user_can, $answer );

					?>
					<div class="ywqa-answers-list">
					<?php

					if ( $replied_by_admin && ! YITH_YWQA()->faq_mode && ! YITH_YWQA()->anonymise_user ) :
						?>
						<span class="admin-answer-symbol">
							<?php
							/**
							 * APPLY_FILTERS: ywqa_answered_by_admin_label
							 *
							 * Filter for the label of the answers made by an administrator.
							 *
							 * @param string the default label.
							 *
							 * @return string
							 */
							echo apply_filters( 'ywqa_answered_by_admin_label', esc_html__( 'Answered by the admin', 'yith-woocommerce-questions-and-answers' ) ); // phpcs:ignore ?>
						</span>
					<?php else : ?>
						<span class="answer-symbol"><?php esc_html_e( 'A', 'yith-woocommerce-questions-and-answers' ); ?></span>
					<?php endif; ?>

						<?php if ( ( YITH_YWQA()->answer_excerpt_length > 0 ) && ( strlen( $answer->content ) > YITH_YWQA()->answer_excerpt_length ) ) : ?>
						<span class="answer"><?php echo substr( $answer->content, 0, YITH_YWQA()->answer_excerpt_length ) . '...'; // phpcs:ignore ?></span>
						<a href="#" rel="nofollow" data-discussion-id="<?php echo esc_attr( $answer->ID ); ?>" class="read-more">
							<?php esc_html_e( 'Read more', 'yith-woocommerce-questions-and-answers' ); ?>
						</a>
					<?php else : ?>
						<span class="answer"><?php echo $answer->content; // phpcs:ignore ?></span>
					<?php endif; ?>

					</div>

						<?php $cnt++; ?>

				<?php } ?>

			<?php else : ?>
				<span class="answer">
					<?php esc_html_e( 'There are no answers for this question yet.', 'yith-woocommerce-questions-and-answers' ); ?>
				</span>
				<?php if ( $only_admin_can_reply && apply_filters( 'yith_wcqa_allow_user_to_reply', true ) ) : ?>
					<a
							href="
							<?php
							echo esc_url(
								add_query_arg(
									array(
										'reply-to-question' => $question->ID,
										'qa' => 1,
									),
									remove_query_arg( 'show-all-questions', get_permalink( $question->product_id ) )
								)
							);
							?>
							"
							rel="nofollow" data-discussion-id="<?php echo esc_attr( $question->ID ); ?>"
							class="goto-question write-first-answer"><?php esc_html_e( 'Answer now', 'yith-woocommerce-questions-and-answers' ); ?></a>
				<?php endif; ?>


			<?php endif; ?>
		</div>


		<?php

		if ( ( $count ) > 1 && 0 !== $answers_to_show && $count > $answers_to_show ) :
			?>
			<div class="all-answers-section">
				<a href="
				<?php
				echo esc_url(
					add_query_arg(
						array(
							'reply-to-question' => $question->ID,
							'qa'                => 1,
						),
						remove_query_arg( 'show-all-questions', get_permalink( $question->product_id ) )
					)
				);
				?>
				"
				rel="nofollow" id="all-answers-<?php echo esc_attr( $question->ID ); ?>" class="all-answers goto-question"
				data-discussion-id="<?php echo esc_attr( $question->ID ); ?>">
				<?php echo sprintf( esc_html__( 'Show all %s answers', 'yith-woocommerce-questions-and-answers' ), $count ); // phpcs:ignore ?>
				</a>
			</div>
		<?php endif; ?>
	</div>
</li>
